<div class="{{class}}">
    <div class="form-group">
        <label for="{{field.full_name}}">{{field.label}}</label>
        <input id="{{field.full_name}}"
               name="{{field.full_name}}"
               class="form-control"
               type="text"
               value="{{field.value_as_str}}"
               {% if tabindex %} tabindex="{{tabindex}}"{% endif %}
               {% if field.placeholder %} placeholder="{{placeholder}}" {% endif %}
               {% if field.disabled %}disabled{% endif %}
        />
        {% for error in field.errors %}
        <div class="red">{{ error }}</div>
        {% endfor %}
    </div>
</div>
