# Generated by Django 2.2 on 2023-05-07 13:42

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('django', '0011_auto_20230211_1150'),
    ]

    operations = [
        #migrations.RemoveField(
        #    model_name='formtemplateitem',
        #    name='form_template',
        #),
        #migrations.DeleteModel(
        #    name='FormTemplate',
        #),
        #migrations.DeleteModel(
        #    name='FormTemplateItem',
        #),
    ]
